#!/bin/sh
# Script to capture SX.e output designed for faxing and emailing via UnForm
# Creates input file of a print stream + FF + coverpage and submits to UnForm
# Written by Synergetic Data Systems Inc.

#
# to run parallel with rxsfax.sh, simply run this script near the top of rxsfax.sh, eg.
# 	uf_rxsfax.sh $1 $2 $3
#

# $1=type, which may end with :debug, which is not passed
# $2=coverpage which ends with a FF
# $3=report text stream

# Modify path for temp files to fit your system, if desired
SubmissionFile="/tmp/ufs.$$.txt"
LocalErrorFile="/tmp/ufs.$$.err"

# Modify path and rule file name to fit your system
RuleFile="Myrulefile.rul"

# Modify UnForm server location (may append :port if you use a non-default port)
Server="localhost"

# Modify output to fit your system
# Normally /dev/null is fine
Output="/dev/null"

# modify UnForm client to fit your system
UnFormClient=uf80c

# send print stream first, plus a FF (on Linux, 'echo' may need to be 'echo -e')
cat $3 >$SubmissionFile

# deal with type:debug
Type=`echo $1|cut -d: -f1`

# send type and coverpage, stripping FF from cover page as it is a trailer page in UnForm
echo "$Type" >>$SubmissionFile
cat $2 | sed -e "s/\f//g" >>$SubmissionFile

# submit to unform
$UnFormClient -i "$SubmissionFile" -e "$LocalErrorFile" -f "$RuleFile" -server "$Server" -o "$Output"

# Clean up work files
rm -f $SubmissionFile 2>/dev/null
rm -f $LocalErrorFile 2>/dev/null

